#!/bin/bash
set -eu -o pipefail

rspec_file=rspec.json

service_names=$(jq -r '.[].name' ${rspec_file})
for service_name in $service_names; do
    if ! lxc-info -n ${service_name}; then
        echo "Creating container: ${service_name}"
        lxc-create -t download -n ${service_name} -- --dist ubuntu --release xenial --arch amd64

        SERVICE=$(jq --arg NAME ${service_name} '.[] | select(.name==$NAME)' ${rspec_file})
        echo $SERVICE
        ip=$(echo $SERVICE | jq -r '.ip_address')
        echo "dhcp-host=${service_name},${ip}" >> /etc/lxc/dnsmasq.conf

        echo "Copying files"
        container_dir="/var/lib/lxc/"${service_name}"/rootfs"
        container_vagrant_dir=${container_dir}"/vagrant"

        mkdir -p ${container_vagrant_dir}
        cp -f /vagrant/reporc "${container_vagrant_dir}"
        cp -rf /vagrant/scripts ${container_vagrant_dir}
        cp -rf /vagrant/clmctest ${container_vagrant_dir}

        # start the container
        lxc-start -n ${service_name}
        sleep 10

        echo "Provisioning: ${service_name}"
        if [ ${service_name} == "clmc-service" ]
        then
            cmd=/vagrant/scripts/clmc-service/install.sh
            lxc-attach -n ${service_name} -- ${cmd}
        elif [ ${service_name} == "test-runner" ]
        then
            cmd=/vagrant/clmctest/services/pytest/install.sh
            lxc-attach -n ${service_name} -- ${cmd}
        else
            location=$(echo $SERVICE | jq -r '.location')
            sf_id=$(echo $SERVICE | jq -r '.sf_id')
            sf_id_instance=$(echo $SERVICE | jq -r '.sf_id_instance')
            sfc_id=$(echo $SERVICE | jq -r '.sfc_id')
            sfc_id_instance=$(echo $SERVICE | jq -r '.sfc_id_instance')
            sr_id=$(echo $SERVICE | jq -r '.sr_id')
            ipendpoint_id=$(echo $SERVICE | jq -r '.ipendpoint_id')
            influxdb_url=$(echo $SERVICE | jq -r '.influxdb_url')
            database_name=$(echo $SERVICE | jq -r '.database_name')

            cmd=/vagrant/clmctest/services/${sf_id}/install.sh
            lxc-attach -n ${service_name} -v REPO_ROOT=/vagrant -- ${cmd}

            cmd=/vagrant/scripts/clmc-agent/install.sh
            lxc-attach -n ${service_name} -v REPO_ROOT=/vagrant -- ${cmd}

            cp -f /vagrant/scripts/clmc-agent/telegraf.conf ${container_dir}/etc/telegraf/
            cp -f /vagrant/scripts/clmc-agent/telegraf_output.conf ${container_dir}/etc/telegraf/telegraf.d/
            cp /vagrant/clmctest/services/${sf_id}/telegraf_${sf_id}.conf ${container_dir}/etc/telegraf/telegraf.d/

            cmd=/vagrant/scripts/clmc-agent/configure_template.sh
            lxc-attach -n ${service_name} -- ${cmd}

            cmd="/vagrant/scripts/clmc-agent/configure.sh ${location} ${sfc_id} ${sfc_id_instance} ${sf_id} ${sf_id_instance} ${ipendpoint_id} ${sr_id} ${influxdb_url} ${database_name}"

            lxc-attach -n ${service_name} -- ${cmd}

            lxc-attach -n ${service_name} -- service telegraf restart
        fi
    fi
done

./conts-stop.sh

service lxc-net restart

./conts-start.sh